@@ -4,6 +4,7 @@ import logging
 import re
 from abc import abstractmethod
 from datetime import datetime, time
+from time import sleep
 from typing import Optional
 
 import requests
@@ -162,7 +163,9 @@ def get_route(date: datetime.date, id_route_t_mos_ru: str, direction: int,
                                     'mgt_schedule[route]': id_route_t_mos_ru,
                                     'mgt_schedule[direction]': direction,
                                 },
-                                headers={'X-Requested-With': 'XMLHttpRequest'}
+                                headers={'X-Requested-With': 'XMLHttpRequest',
+                                         'User-Agent': 'Mozilla/5.0 (Linux; Android 6.0; Nexus 5 Build/MRA58N) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/108.0.0.0 Mobile Safari/537.36'
+                                         }
                                 )
         if response.status_code == 200:
             logger.info("Get route #{}".format(id_route_t_mos_ru))
@@ -217,7 +220,9 @@ def get_list_routes(work_time: int, direction: int,
                                             'page': page,
                                             'mgt_schedule[direction]': direction,
                                         }
-                                        , headers={'X-Requested-With': 'XMLHttpRequest'}
+                                        , headers={'X-Requested-With': 'XMLHttpRequest',
+                                                   'User-Agent': 'Mozilla/5.0 (Linux; Android 6.0; Nexus 5 Build/MRA58N) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/108.0.0.0 Mobile Safari/537.36'
+                                                   }
                                         # , headers={'Cookie': "_ym_d=1637468102; _ym_uid=1637468102592825648; mos_id=rBEAAmGaFNawBwAOHRgWAgA=; _ga=GA1.2.1733238845.1637487830; uxs_uid=147e2110-500d-11ec-a7cb-8bb8b12c3186; KFP_DID=ee285837-cd1f-0a9b-c8a2-9cef6a4ee333; _ym_isad=2; _ym_visorc=w"}
                                         )
                 if response.status_code == 200:
@@ -234,6 +239,8 @@ def get_list_routes(work_time: int, direction: int,
                 page = page + 1
                 if page > count:
                     finish = True
+                if not finish:
+                    sleep(5)
             except requests.exceptions.RequestException as e:
                 logger.error("Error " + str(e))
                 repeat = True
